import React, { useState, useEffect } from 'react';
import { createChatBotMessage } from 'react-chatbot-kit';
import '../../../App.css';
import '../../../Options.css';
import '../../../Quiz.css';

const Options = (props) => {
  const options = [
    {
      text: 'Javascript',
      handler: props.actionProvider.handleJavascriptQuiz,
      id: 1,
    },
    { text: 'Python', handler: () => {}, id: 2 },
    { text: 'Golang', handler: () => {}, id: 3 },
  ];

  const buttonsMarkup = options.map((option) => (
    <button key={option.id} onClick={option.handler} className="option-button">
      {option.text}
    </button>
  ));

  return <div className="options-container">{buttonsMarkup}</div>;
};

const FlashCard = ({ question, answer, incrementIndex }) => {
  const [showAnswer, setShowAnswer] = useState(false);

  useEffect(() => setShowAnswer(false), [question]);

  return (
    <>
      <div
        className="flashcard-container"
        onClick={() => setShowAnswer(!showAnswer)}
      >
        {!showAnswer && question}
        {showAnswer && answer}
      </div>
      {showAnswer && (
        <button onClick={incrementIndex} className="flashcard-button">
          Next question
        </button>
      )}
    </>
  );
};

const Quiz = (props) => {
  console.log(props);
  let [questionIndex, setQuestionIndex] = useState(0);

  const incrementIndex = () => setQuestionIndex((prev) => (prev += 1));

  const currentQuestion = props.questions[questionIndex];

  if (!currentQuestion) {
    return <p>Quiz over.</p>;
  }

  return (
    <FlashCard
      question={currentQuestion.question}
      answer={currentQuestion.answer}
      incrementIndex={incrementIndex}
    />
  );
};

const config = {
  botName: 'LearningBot',
  initialMessages: [
    createChatBotMessage(`Hello. What do you want to learn`, {
      widget: 'options',
    }),
  ],
  widgets: [
    {
      widgetName: 'options',
      widgetFunc: (props) => <Options {...props} />,
    },
    {
      widgetName: 'javascriptQuiz',
      widgetFunc: (props) => <Quiz {...props} />,
      props: {
        questions: [
          {
            question: 'What is closure?',
            answer:
              "Closure is a way for a function to retain access to it's enclosing function scope after the execution of that function is finished.",
            id: 1,
          },
          {
            question: 'Explain prototypal inheritance',
            answer:
              'Prototypal inheritance is a link between an object and an object store that holds shared properties. If a property is not found on the host object, javascript will check the prototype object.',
            id: 2,
          },
        ],
      },
    },
  ],
};

export default config;
